@@ -263,8 +263,10 @@ class HtmlFormatter(TextFormatter):
     def get_css():
         """Return CSS for generated HTML page."""
         return """
+div:has(> [class^="nDk"]) {cursor: pointer}
+div:has(> [class^="nDv"]) {cursor: text}
 [class^="nDk"] {cursor: pointer}
-[class^="nDk"], [class^="nDv"] {
+[class^="nDk"], [class^="nDv"]:not(.nDvD) {
     border-radius: 2px;
     display: inline;
 }
@@ -345,8 +347,8 @@ document.querySelector('.nDvD').addEventListener('click', event => {
         dif.__nDh = dif.offsetHeight;
         dif.style.height = '0px';
         PREV = null;
-        dif.__nDc = tgt.innerHTML.substring(1, 2);
-        tgt.innerHTML = tgt.innerHTML.replace(/^./, '*');
+        dif.__nDc = tgt.innerHTML.substring(0, 1);
+        tgt.innerHTML = tgt.innerHTML.replace(/^./, '&#9660;');
         tgt.style.fontWeight = 'bold'
     }
 })
